changeset 22423:c952e97b4316

Merge.
author Doug Simon <doug.simon@oracle.com>
date Tue, 11 Aug 2015 00:10:16 +0200
parents 440c505123b4 (current diff) a440d1dc6513 (diff)
children 8d916886ae68
files
diffstat 1 files changed, 5 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/debug/BenchmarkCounters.java	Mon Aug 10 16:33:57 2015 +0200
+++ b/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/debug/BenchmarkCounters.java	Tue Aug 11 00:10:16 2015 +0200
@@ -46,8 +46,8 @@
  * <p>
  *
  * The counters are kept in a special area allocated for each native JavaThread object, and the
  * number of counters is configured using {@code -XX:GraalCounterSize=value}.
  * {@code -XX:+/-GraalCountersExcludeCompiler} configures whether to exclude compiler threads
  * (defaults to true).
  *
  * The subsystems that use the logging need to have their own options to turn on the counters, and
@@ -59,9 +59,9 @@
  * <h1>Example</h1> In order to create statistics about allocations within the DaCapo pmd benchmark
  * the following steps are necessary:
  * <ul>
- * <li>Set {@code -XX:GraalCounterSize=value}. The actual required value depends on the granularity
+ * <li>Set {@code -XX:JVMCICounterSize=value}. The actual required value depends on the granularity
  * of the profiling, 10000 should be enough for most cases.</li>
- * <li>Also: {@code -XX:+/-GraalCountersExcludeCompiler} specifies whether the numbers generated by
+ * <li>Also: {@code -XX:+/-JVMCICountersExcludeCompiler} specifies whether the numbers generated by
  * compiler threads should be excluded (default: true).</li>
  * <li>Start the DaCapo pmd benchmark with
  * {@code "-G:BenchmarkDynamicCounters=err, starting ====, PASSED in "} and
@@ -143,7 +143,7 @@
         assert counter.group.equals(group) : "mismatching groups: " + counter.group + " vs. " + group;
         int countersSize = config.jvmciCountersSize;
         if (counter.index >= countersSize) {
-            throw new JVMCIError("too many counters, reduce number of counters or increase -XX:GraalCounterSize=... (current value: " + countersSize + ")");
+            throw new JVMCIError("too many counters, reduce number of counters or increase -XX:JVMCICounterSize=... (current value: " + countersSize + ")");
         }
         return counter;
     }
@@ -46,8 +46,8 @@
  *
  * The counters are kept in a special area allocated for each native JavaThread object, and the
- * number of counters is configured using {@code -XX:GraalCounterSize=value}.
- * {@code -XX:+/-GraalCountersExcludeCompiler} configures whether to exclude compiler threads
+ * number of counters is configured using {@code -XX:JVMCICounterSize=value}.
+ * {@code -XX:+/-JVMCICountersExcludeCompiler} configures whether to exclude compiler threads
  * (defaults to true).
  *